@@ -350,7 +350,7 @@ from openpyxl.chart.series import DataPoint
 
 from analytics_sdk.utilities import (
     BASE_API_URL,
-    PLATFORM_ROUTE,
+    APP_ID,
     API_KEY,
     API_SECRET,
     API_RETRY
@@ -602,7 +602,7 @@ class ExcelRenderer:
 
         ws.merge_cells('B3:Z4')
         cell = ws['B3']
-        cell.value = PLATFORM_ROUTE
+        cell.value = APP_ID.lower()
         cell.font = Font(color="00598B", bold=True)
         cell.alignment = Alignment(vertical="center")
         cell.fill = PatternFill("solid", fgColor="eeeeee")
@@ -709,7 +709,7 @@ class ExcelRenderer:
 
         ws.merge_cells('B1:Z2')
         cell = ws['B1']
-        cell.value = PLATFORM_ROUTE.title()
+        cell.value = APP_ID.title()
         cell.font = Font(color="00598B", bold=True)
         cell.fill = PatternFill("solid", fgColor="eeeeee")
         cell.alignment = Alignment(vertical="center")
