@@ -175,7 +175,7 @@ def get_epoc_from_datetime_string(str_datetime):
 def get_result_by_run(run_id, field=None, default_value=None):
     try:
         s3 = get_s3_client()
-        run_id= f'analytics-apps/{PLATFORM_ROUTE}/{run_id}/json/{run_id}'
+        run_id= f'{PLATFORM_ROUTE}/{run_id}/json/{run_id}'
         res_object = s3.get_object(Bucket=BUCKET_NAME,Key=run_id)
         serializedObject = res_object['Body'].read()
         result = json.loads(serializedObject)
@@ -339,10 +339,10 @@ def delete_excel_file(source_path):
 def generate_excel_file(run_id, orgId):
     logger.info('Entered into excel generation process')
     excel_data=get_result_by_run(run_id, 'excel-data', {})
-    reportname = f"{PLATFORM_ROUTE}" + '-' + datetime.now().strftime('%Y-%m-%d-%I-%M-%S') + '.xlsx'
+    reportname = f"{APP_ID.lower()}" + '-' + datetime.now().strftime('%Y-%m-%d-%I-%M-%S') + '.xlsx'
     filepath = './' + reportname
     generate_excel(excel_data, orgId, filepath)
-    excel_file_location = f'analytics-apps/{PLATFORM_ROUTE}/{run_id}/excel/' + reportname
+    excel_file_location = f'{PLATFORM_ROUTE}/{run_id}/excel/' + reportname
     
     excel_url = upload_excel_s3(filepath, BUCKET_NAME, excel_file_location)
     return excel_url
